.. _api-views-project:

=============
Project views
=============

Return to :ref:`api-views`.

.. automodule:: projector.views.project

.. view:: ProjectView

ProjectView
===========

.. autoclass:: projector.views.project.ProjectView
   :members:

